@@ -1,4 +1,4 @@
-#!/usr/local/bin/python3.7
+#!/usr/local/bin/python3.8
 
 # Copyright (C) 2003-2007  Robey Pointer <robeypointer@gmail.com>
 #
@@ -31,6 +31,7 @@ import traceback
 from paramiko.py3compat import input
 
 import paramiko
+
 try:
     import interactive
 except ImportError:
@@ -42,71 +43,73 @@ def agent_auth(transport, username):
     Attempt to authenticate to the given transport using any of the private
     keys available from an SSH agent.
     """
-    
+
     agent = paramiko.Agent()
     agent_keys = agent.get_keys()
     if len(agent_keys) == 0:
         return
-        
+
     for key in agent_keys:
-        print('Trying ssh-agent key %s' % hexlify(key.get_fingerprint()))
+        print("Trying ssh-agent key %s" % hexlify(key.get_fingerprint()))
         try:
             transport.auth_publickey(username, key)
-            print('... success!')
+            print("... success!")
             return
         except paramiko.SSHException:
-            print('... nope.')
+            print("... nope.")
 
 
 def manual_auth(username, hostname):
-    default_auth = 'p'
-    auth = input('Auth by (p)assword, (r)sa key, or (d)ss key? [%s] ' % default_auth)
+    default_auth = "p"
+    auth = input(
+        "Auth by (p)assword, (r)sa key, or (d)ss key? [%s] " % default_auth
+    )
     if len(auth) == 0:
         auth = default_auth
 
-    if auth == 'r':
-        default_path = os.path.join(os.environ['HOME'], '.ssh', 'id_rsa')
-        path = input('RSA key [%s]: ' % default_path)
+    if auth == "r":
+        default_path = os.path.join(os.environ["HOME"], ".ssh", "id_rsa")
+        path = input("RSA key [%s]: " % default_path)
         if len(path) == 0:
             path = default_path
         try:
             key = paramiko.RSAKey.from_private_key_file(path)
         except paramiko.PasswordRequiredException:
-            password = getpass.getpass('RSA key password: ')
+            password = getpass.getpass("RSA key password: ")
             key = paramiko.RSAKey.from_private_key_file(path, password)
         t.auth_publickey(username, key)
-    elif auth == 'd':
-        default_path = os.path.join(os.environ['HOME'], '.ssh', 'id_dsa')
-        path = input('DSS key [%s]: ' % default_path)
+    elif auth == "d":
+        default_path = os.path.join(os.environ["HOME"], ".ssh", "id_dsa")
+        path = input("DSS key [%s]: " % default_path)
         if len(path) == 0:
             path = default_path
         try:
             key = paramiko.DSSKey.from_private_key_file(path)
         except paramiko.PasswordRequiredException:
-            password = getpass.getpass('DSS key password: ')
+            password = getpass.getpass("DSS key password: ")
             key = paramiko.DSSKey.from_private_key_file(path, password)
         t.auth_publickey(username, key)
     else:
-        pw = getpass.getpass('Password for %s@%s: ' % (username, hostname))
+        pw = getpass.getpass("Password for %s@%s: " % (username, hostname))
         t.auth_password(username, pw)
 
 
 # setup logging
-paramiko.util.log_to_file('demo.log')
+paramiko.util.log_to_file("demo.log")
 
-username = ''
+username = ""
 if len(sys.argv) > 1:
     hostname = sys.argv[1]
-    if hostname.find('@') >= 0:
-        username, hostname = hostname.split('@')
+    if hostname.find("@") >= 0:
+        username, hostname = hostname.split("@")
 else:
-    hostname = input('Hostname: ')
+    hostname = input("Hostname: ")
 if len(hostname) == 0:
-    print('*** Hostname required.')
+    print("*** Hostname required.")
     sys.exit(1)
 port = 22
-if hostname.find(':') >= 0:
-    hostname, portstr = hostname.split(':')
+if hostname.find(":") >= 0:
+    hostname, portstr = hostname.split(":")
     port = int(portstr)
 
 # now connect
@@ -114,7 +117,7 @@ try:
     sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
     sock.connect((hostname, port))
 except Exception as e:
-    print('*** Connect failed: ' + str(e))
+    print("*** Connect failed: " + str(e))
     traceback.print_exc()
     sys.exit(1)
 
@@ -123,34 +126,38 @@ try:
     try:
         t.start_client()
     except paramiko.SSHException:
-        print('*** SSH negotiation failed.')
+        print("*** SSH negotiation failed.")
         sys.exit(1)
 
     try:
-        keys = paramiko.util.load_host_keys(os.path.expanduser('~/.ssh/known_hosts'))
+        keys = paramiko.util.load_host_keys(
+            os.path.expanduser("~/.ssh/known_hosts")
+        )
     except IOError:
         try:
-            keys = paramiko.util.load_host_keys(os.path.expanduser('~/ssh/known_hosts'))
+            keys = paramiko.util.load_host_keys(
+                os.path.expanduser("~/ssh/known_hosts")
+            )
         except IOError:
-            print('*** Unable to open host keys file')
+            print("*** Unable to open host keys file")
             keys = {}
 
     # check server's host key -- this is important.
     key = t.get_remote_server_key()
     if hostname not in keys:
-        print('*** WARNING: Unknown host key!')
+        print("*** WARNING: Unknown host key!")
     elif key.get_name() not in keys[hostname]:
-        print('*** WARNING: Unknown host key!')
+        print("*** WARNING: Unknown host key!")
     elif keys[hostname][key.get_name()] != key:
-        print('*** WARNING: Host key has changed!!!')
+        print("*** WARNING: Host key has changed!!!")
         sys.exit(1)
     else:
-        print('*** Host key OK.')
+        print("*** Host key OK.")
 
     # get username
-    if username == '':
+    if username == "":
         default_username = getpass.getuser()
-        username = input('Username [%s]: ' % default_username)
+        username = input("Username [%s]: " % default_username)
         if len(username) == 0:
             username = default_username
 
@@ -158,25 +165,23 @@ try:
     if not t.is_authenticated():
         manual_auth(username, hostname)
     if not t.is_authenticated():
-        print('*** Authentication failed. :(')
+        print("*** Authentication failed. :(")
         t.close()
         sys.exit(1)
 
     chan = t.open_session()
     chan.get_pty()
     chan.invoke_shell()
-    print('*** Here we go!\n')
+    print("*** Here we go!\n")
     interactive.interactive_shell(chan)
     chan.close()
     t.close()
 
 except Exception as e:
-    print('*** Caught exception: ' + str(e.__class__) + ': ' + str(e))
+    print("*** Caught exception: " + str(e.__class__) + ": " + str(e))
     traceback.print_exc()
     try:
         t.close()
     except:
         pass
     sys.exit(1)
-
-
