@@ -47,11 +47,13 @@ def handler(chan, host, port):
     try:
         sock.connect((host, port))
     except Exception as e:
-        verbose('Forwarding request to %s:%d failed: %r' % (host, port, e))
+        verbose("Forwarding request to %s:%d failed: %r" % (host, port, e))
         return
-    
-    verbose('Connected!  Tunnel open %r -> %r -> %r' % (chan.origin_addr,
-                                                        chan.getpeername(), (host, port)))
+
+    verbose(
+        "Connected!  Tunnel open %r -> %r -> %r"
+        % (chan.origin_addr, chan.getpeername(), (host, port))
+    )
     while True:
         r, w, x = select.select([sock, chan], [], [])
         if sock in r:
@@ -66,16 +68,18 @@ def handler(chan, host, port):
             sock.send(data)
     chan.close()
     sock.close()
-    verbose('Tunnel closed from %r' % (chan.origin_addr,))
+    verbose("Tunnel closed from %r" % (chan.origin_addr,))
 
 
 def reverse_forward_tunnel(server_port, remote_host, remote_port, transport):
-    transport.request_port_forward('', server_port)
+    transport.request_port_forward("", server_port)
     while True:
         chan = transport.accept(1000)
         if chan is None:
             continue
-        thr = threading.Thread(target=handler, args=(chan, remote_host, remote_port))
+        thr = threading.Thread(
+            target=handler, args=(chan, remote_host, remote_port)
+        )
         thr.setDaemon(True)
         thr.start()
 
@@ -95,40 +99,88 @@ network. This is similar to the openssh -R option.
 
 def get_host_port(spec, default_port):
     "parse 'hostname:22' into a host and port, with the port optional"
-    args = (spec.split(':', 1) + [default_port])[:2]
+    args = (spec.split(":", 1) + [default_port])[:2]
     args[1] = int(args[1])
     return args[0], args[1]
 
 
 def parse_options():
     global g_verbose
-    
-    parser = OptionParser(usage='usage: %prog [options] <ssh-server>[:<server-port>]',
-                          version='%prog 1.0', description=HELP)
-    parser.add_option('-q', '--quiet', action='store_false', dest='verbose', default=True,
-                      help='squelch all informational output')
-    parser.add_option('-p', '--remote-port', action='store', type='int', dest='port',
-                      default=DEFAULT_PORT,
-                      help='port on server to forward (default: %d)' % DEFAULT_PORT)
-    parser.add_option('-u', '--user', action='store', type='string', dest='user',
-                      default=getpass.getuser(),
-                      help='username for SSH authentication (default: %s)' % getpass.getuser())
-    parser.add_option('-K', '--key', action='store', type='string', dest='keyfile',
-                      default=None,
-                      help='private key file to use for SSH authentication')
-    parser.add_option('', '--no-key', action='store_false', dest='look_for_keys', default=True,
-                      help='don\'t look for or use a private key file')
-    parser.add_option('-P', '--password', action='store_true', dest='readpass', default=False,
-                      help='read password (for key or password auth) from stdin')
-    parser.add_option('-r', '--remote', action='store', type='string', dest='remote', default=None, metavar='host:port',
-                      help='remote host and port to forward to')
+
+    parser = OptionParser(
+        usage="usage: %prog [options] <ssh-server>[:<server-port>]",
+        version="%prog 1.0",
+        description=HELP,
+    )
+    parser.add_option(
+        "-q",
+        "--quiet",
+        action="store_false",
+        dest="verbose",
+        default=True,
+        help="squelch all informational output",
+    )
+    parser.add_option(
+        "-p",
+        "--remote-port",
+        action="store",
+        type="int",
+        dest="port",
+        default=DEFAULT_PORT,
+        help="port on server to forward (default: %d)" % DEFAULT_PORT,
+    )
+    parser.add_option(
+        "-u",
+        "--user",
+        action="store",
+        type="string",
+        dest="user",
+        default=getpass.getuser(),
+        help="username for SSH authentication (default: %s)"
+        % getpass.getuser(),
+    )
+    parser.add_option(
+        "-K",
+        "--key",
+        action="store",
+        type="string",
+        dest="keyfile",
+        default=None,
+        help="private key file to use for SSH authentication",
+    )
+    parser.add_option(
+        "",
+        "--no-key",
+        action="store_false",
+        dest="look_for_keys",
+        default=True,
+        help="don't look for or use a private key file",
+    )
+    parser.add_option(
+        "-P",
+        "--password",
+        action="store_true",
+        dest="readpass",
+        default=False,
+        help="read password (for key or password auth) from stdin",
+    )
+    parser.add_option(
+        "-r",
+        "--remote",
+        action="store",
+        type="string",
+        dest="remote",
+        default=None,
+        metavar="host:port",
+        help="remote host and port to forward to",
+    )
     options, args = parser.parse_args()
 
     if len(args) != 1:
-        parser.error('Incorrect number of arguments.')
+        parser.error("Incorrect number of arguments.")
     if options.remote is None:
-        parser.error('Remote address required (-r).')
-    
+        parser.error("Remote address required (-r).")
+
     g_verbose = options.verbose
     server_host, server_port = get_host_port(args[0], SSH_PORT)
     remote_host, remote_port = get_host_port(options.remote, SSH_PORT)
@@ -137,31 +189,42 @@ def parse_options():
 
 def main():
     options, server, remote = parse_options()
-    
+
     password = None
     if options.readpass:
-        password = getpass.getpass('Enter SSH password: ')
-    
+        password = getpass.getpass("Enter SSH password: ")
+
     client = paramiko.SSHClient()
     client.load_system_host_keys()
     client.set_missing_host_key_policy(paramiko.WarningPolicy())
 
-    verbose('Connecting to ssh host %s:%d ...' % (server[0], server[1]))
+    verbose("Connecting to ssh host %s:%d ..." % (server[0], server[1]))
     try:
-        client.connect(server[0], server[1], username=options.user, key_filename=options.keyfile,
-                       look_for_keys=options.look_for_keys, password=password)
+        client.connect(
+            server[0],
+            server[1],
+            username=options.user,
+            key_filename=options.keyfile,
+            look_for_keys=options.look_for_keys,
+            password=password,
+        )
     except Exception as e:
-        print('*** Failed to connect to %s:%d: %r' % (server[0], server[1], e))
+        print("*** Failed to connect to %s:%d: %r" % (server[0], server[1], e))
         sys.exit(1)
 
-    verbose('Now forwarding remote port %d to %s:%d ...' % (options.port, remote[0], remote[1]))
+    verbose(
+        "Now forwarding remote port %d to %s:%d ..."
+        % (options.port, remote[0], remote[1])
+    )
 
     try:
-        reverse_forward_tunnel(options.port, remote[0], remote[1], client.get_transport())
+        reverse_forward_tunnel(
+            options.port, remote[0], remote[1], client.get_transport()
+        )
     except KeyboardInterrupt:
-        print('C-c: Port forwarding stopped.')
+        print("C-c: Port forwarding stopped.")
         sys.exit(0)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
